Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code

Unified Diff: include/AdblockPlus/IFileSystem.h

Issue 29535572: Issue 5183 - make FileSystemPtr std::unique_ptr (Closed) Base URL: https://github.com/adblockplus/libadblockplus.git
Patch Set: Created Sept. 4, 2017, 9:59 a.m.
Use n/p to move between diff chunks; N/P to move between comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | test/BaseJsTest.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/AdblockPlus/IFileSystem.h
diff --git a/include/AdblockPlus/IFileSystem.h b/include/AdblockPlus/IFileSystem.h
index 54b56be0cd5a0c53ec4a20a67d15f08a54f4e9f4..619b27139b6b1b744c2aaa2b11b44453d03f90e6 100644
--- a/include/AdblockPlus/IFileSystem.h
+++ b/include/AdblockPlus/IFileSystem.h
@@ -125,9 +125,9 @@ namespace AdblockPlus
};
/**
* Shared smart pointer to a `IFileSystem` instance.
*/
- typedef std::shared_ptr<IFileSystem> FileSystemPtr;
+ typedef std::unique_ptr<IFileSystem> FileSystemPtr;
}
#endif
« no previous file with comments | « no previous file | test/BaseJsTest.cpp » ('j') | no next file with comments »
@@ -125,9 +125,9 @@ namespace AdblockPlus
};
/**
- * Shared smart pointer to a `IFileSystem` instance.
+ * Unique smart pointer to to a `IFileSystem` instance.
*/

Powered by Google App Engine
This is Rietveld